.. _utils:

=====
Utils
=====

.. autofunction:: nuaal.utils.utils.get_logger

.. autofunction:: nuaal.utils.utils.interface_split

.. autofunction:: nuaal.utils.utils.vlan_range_shortener

.. autofunction:: nuaal.utils.utils.vlan_range_expander

.. autofunction:: nuaal.utils.utils.int_name_convert

.. autofunction:: nuaal.utils.utils.mac_addr_convert

.. autofunction:: nuaal.utils.utils.update_dict

.. autofunction:: nuaal.utils.utils.check_path

.. _Filter:

Filter
======
.. autoclass:: nuaal.utils.Filter
    :members:
    :undoc-members:
    :private-members:
    :show-inheritance:

.. _OutputFilter:

OutputFilter
============
.. autoclass:: nuaal.utils.OutputFilter
    :members:
    :undoc-members:
    :private-members:
    :show-inheritance:
